Index: src/uk/me/parabola/splitter/ProblemListProcessor.java
===================================================================
--- src/uk/me/parabola/splitter/ProblemListProcessor.java	(revision 590)
+++ src/uk/me/parabola/splitter/ProblemListProcessor.java	(working copy)
@@ -55,6 +55,7 @@
 	private final HashSet<String> wantedBoundaryAdminLevels = new HashSet<>();
 	
 	private final HashSet<String> wantedBoundaryTagValues;
+	private final HashSet<String> wantedRouteTagValues;
 	
 	ProblemListProcessor(DataStorer dataStorer, int areaOffset,
 			int numAreasThisPass, SplitterParams mainOptions) {
@@ -83,6 +84,13 @@
 			wantedBoundaryTagValues = new HashSet<>(Arrays.asList(boundaryTags));
 		}
 		setWantedAdminLevel(mainOptions.getWantedAdminLevel());
+		String routeRelationValuesParm = mainOptions.getRouteRelValues();
+		if (routeRelationValuesParm.isEmpty()) {
+			wantedRouteTagValues = null;
+		} else {
+			String[] routeValues = routeRelationValuesParm.split(Pattern.quote(","));
+			wantedRouteTagValues = new HashSet<>(Arrays.asList(routeValues));
+		}
 	}
 	
 	public void setWantedAdminLevel(int adminLevel) {
@@ -205,6 +213,8 @@
 		boolean isMPRelType = false;
 		boolean hasBoundaryTag = false;
 		boolean isWantedBoundary = (wantedBoundaryTagValues == null) ? true:false;
+		boolean isRouteRelType = false;
+		boolean isWantedRoute = (wantedRouteTagValues == null) ? false : true;
 		Iterator<Element.Tag> tags = rel.tagsIterator();
 		String admin_level = null;
 		while(tags.hasNext()) {
@@ -214,6 +224,8 @@
 					useThis= true; // no need to check other tags
 				else if ("multipolygon".equals((t.value))  || "boundary".equals((t.value)))
 					isMPRelType= true;
+				else if ("route".equals(t.value))
+					isRouteRelType = true;
 				else if ("associatedStreet".equals((t.value))  || "street".equals((t.value)))
 					useThis= true; // no need to check other tags
 			} else if ("boundary".equals(t.key)){
@@ -228,7 +240,12 @@
 			} else if ("admin_level".equals(t.key)){
 				admin_level = t.value;
 			}
-			
+			if ("route".equals((t.value))) {
+				if (wantedRouteTagValues != null) {
+					if (wantedRouteTagValues.contains(t.value))
+						isWantedRoute = true;
+				}
+			} 			
 			if (useThis)
 				break;
 		}
@@ -237,7 +254,8 @@
 		else if (isMPRelType && hasBoundaryTag  && admin_level != null){
 			if (wantedBoundaryAdminLevels.contains(admin_level))
 				useThis = true;
-		}
+		} else if (isRouteRelType && isWantedRoute)
+			useThis = true;
 		if (!useThis){
 			return;
 		}
Index: src/uk/me/parabola/splitter/args/SplitterParams.java
===================================================================
--- src/uk/me/parabola/splitter/args/SplitterParams.java	(revision 590)
+++ src/uk/me/parabola/splitter/args/SplitterParams.java	(working copy)
@@ -112,7 +112,6 @@
 			+ "Used to filter boundary relations for problem-list processing. Ignored when keep-complete is false.")
 	int getWantedAdminLevel();
 	
-	
 
 	@Option(defaultValue = "200000", description = "Search limit in split algo. Higher values may find better splits, but will take longer.")
 	int getSearchLimit();
@@ -123,4 +122,8 @@
 	@Option(defaultValue = "false", description = "Specify if splitter should ignore bounds tags in input files")
 	boolean getIgnoreOsmBounds();
 
+	@Option(defaultValue="", description = "A comma separated list of tag values for route relations. " 
+			+ "Can be used to keep route relations of the given type complete. Only route values listed are kept complete. Default is empty.")
+	String getRouteRelValues();
+	
 }
